==> App-GitWorkspaceScanner-v1.0.0.tar.gz: App-GitWorkspaceScanner-v1.0.0/README.md <==
App-GitWorkspaceScanner
=======================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitWorkspaceScanner.svg?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitWorkspaceScanner)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitWorkspaceScanner/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitWorkspaceScanner?branch=master)
[![Latest Version](https://img.shields.io/github/tag/guillaumeaubert/App-GitWorkspaceScanner.svg?style=flat)](https://metacpan.org/release/App-GitWorkspaceScanner)

`App::GitWorkspaceScanner` scans git repositories in your workspace for local
changes not synced up.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitWorkspaceScanner


You can also look for information at:

 * [GitHub (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitWorkspaceScanner/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitWorkspaceScanner)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitWorkspaceScanner)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitWorkspaceScanner)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2014-2015 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> App-GitWorkspaceScanner-v1.0.2.tar.gz: App-GitWorkspaceScanner-v1.0.2/README.md <==
App-GitWorkspaceScanner
=======================

[![Build Status](https://travis-ci.org/guillaumeaubert/App-GitWorkspaceScanner.svg?branch=master)](https://travis-ci.org/guillaumeaubert/App-GitWorkspaceScanner)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/App-GitWorkspaceScanner/badge.svg?branch=master)](https://coveralls.io/r/guillaumeaubert/App-GitWorkspaceScanner?branch=master)
[![CPAN](https://img.shields.io/cpan/v/App-GitWorkspaceScanner.svg)](https://metacpan.org/release/App-GitWorkspaceScanner)

`App::GitWorkspaceScanner` scans git repositories in your workspace for local
changes not synced up.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc App::GitWorkspaceScanner


You can also look for information at:

 * [GitHub (report bugs here)]
   (https://github.com/guillaumeaubert/App-GitWorkspaceScanner/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/App-GitWorkspaceScanner)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/App-GitWorkspaceScanner)

 * [MetaCPAN]
   (https://metacpan.org/release/App-GitWorkspaceScanner)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2014-2015 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
